#ifndef _INIT_H
#define _INIT_H

#include <types.h>
#include <affichage.h>

#include <ctype.h>
#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
#include <getopt.h>

#include <curses.h>
#include <MlvTypeC.h>

/* Gnre un point alatoire sur le damier.
 * Si le boolen ferme vaut VRAI, le gnrateur alatoire est ferm et aucun
 * point alatoire n'est ralis. Fonctionnalit utilise quand le programme
 * se termine.
 * /dev/urandom n'est ainsi ouvert qu'une seule fois.
 */
bool random_point(Point * p, bool ferme, Damier * dam);

/* Initialise Curses :
 * Passe le terminal en mode brut et en mode non-bloquant
 * Active les touches KEY_*
 * Empche l'affichage sur le terminal quand on appuie sur une touche
 * Active les couleurs dans ncurses
 * Dsactive l'affichage du curseur
 */
void init_curses(void);

/* Cr une fentre nomme nibbler pour mlvlib */
bool init_mlv(void ** mlvstr);

/* Initialisation du damier */
bool init_damier(Damier * dam);

/* Initialisation des proies */
bool init_proies(Damier * dam);

/* Initialisation du ver */
bool init_ver(Ver * ver, Damier *dam);

/* "Parse" les options de la ligne de commande */
void options(int argc, char **argv, Damier * dam, Ver * ver, Affichage * aff);

/* Met les valeurs par dfaut pour le programme.
 * Parse les options passes en argument au programme.
 * Initialise le damier, les proies et le ver.
 * str_aff est un pointeur vers une structure de donnes pour l'interface
 * utilisateur.
 */
bool init(int argc, char **argv, Affichage *aff, Damier * dam, Ver * ver,
	void ** str_aff);

/* Libration de la file du ver */
void libere_ver(Ver * ver);

/* Libration du damier */
void libere_dam(Damier * dam);

/* Libre toutes les donnes alloues pendant l'utilisation du programme */
void libere(Damier * dam, Ver * ver, Affichage aff, void ** str_aff);

#endif /* _INIT_H */
