#include <affichage.h>

/* Affiche en fonction du mode d'affichage choisit  l'initialisation du 
 * programme.
 * struct_aff est un pointeur sur une structure servant  l'affichage
 * par une bibliothque quelconque
 */
void affichage(Damier * dam, Affichage aff, void * structaff)
{
    switch(aff) {
	case TXT:
	    affichage_txt(dam);
	    break;
	case MLV:
	    affichage_mlv(dam,structaff);
	    break;
    }
}

/* Affiche sur fond vert, les anneaux du ver en rouge, la tte en magenta.
 * Les proies sont des carrs blancs.
 */
void affichage_txt(Damier * dam)
{
    int i,j;

    for ( i=0 ; i < dam->lignes ; i++ ) {
	for ( j=0 ; j < dam->colonnes ; j++ )
	    switch(dam->tab[i][j]) {
		case VIDE:
		    affiche_case(j*2,i,VERT);
		    break;
		case PROIE:
		    affiche_case(j*2,i,BLANC);
		    break;
		case ANNEAU:
		    affiche_case(j*2,i,ROUGE);
		    break;
		case TETE:
		    affiche_case(j*2,i,MAGENTA);
		    break;
	    }
    }
    mvprintw(dam->lignes,0,"Proies : %d",dam->nbproies);
    clrtoeol();
}

/* Affichage  l'aide de la bibliothque MLV.
 * La taille des cases du damier est calcule en fonction du nombre de cases
 *  afficher. Ceci permet d'avoir une fentre toujours de mme taille, si tel
 * n'tait pas le cas ( si on utilisait une taille de case fixe ), la
 * bibliothque MLV refuserait d'afficher des damiers trop grands car la
 * fentre serait trop grande
 */
void affichage_mlv(Damier * dam, MlvType * screen)
{
    int i,j,t_cases;
    char msg[100];

    /* t_cases contient la taille des cases */
    t_cases = MIN(MLV_LARG/dam->colonnes, MLV_HAUT/dam->lignes);

    draw_filled_rectangle(0,0,MLV_LARG,MLV_HAUT,"white",screen);

    for ( i=0 ; i < dam->lignes ; i++ )
	for ( j=0 ; j < dam->colonnes ; j++ ) {
	    /* Fond de la case : verte avec une bordure */
	    draw_filled_rectangle(j*t_cases,i*t_cases,t_cases,t_cases,
		    "forest green",screen);
	    draw_rectangle(j*t_cases,i*t_cases,t_cases,t_cases,
		    "dark green",screen);
	    /* Contenu */
	    switch(dam->tab[i][j]) {
		case VIDE:
		    break;
		case PROIE:
		    draw_filled_circle(j*t_cases+t_cases/2,i*t_cases+t_cases/2,
			    t_cases/2,"white",screen);
		    break;
		case ANNEAU:
		    draw_filled_circle(j*t_cases+t_cases/2,i*t_cases+t_cases/2,
			    t_cases/2,"red",screen);
		    break;
		case TETE:
		    draw_filled_circle(j*t_cases+t_cases/2,i*t_cases+t_cases/2,
			    t_cases/2,"magenta",screen);
		    break;
	    }
	}
    sprintf(msg,"Proies : %d",dam->nbproies);
    draw_string(0,MLV_HAUT-2,msg,POLICE,"black",screen);

    display_window(screen);    
}

/* Affiche gameover au centre du terminal */
void gameover_txt(void)
{
    int h, w;
    getmaxyx(stdscr,h,w);

    clear();
    mvprintw(h/2,w/2-4,"GAME OVER");
    refresh();
}

/* Affiche gameover au centre de la fentre avec MlvLib */
void gameover_mlv(MlvType * screen)
{
    draw_filled_rectangle(0,0,MLV_LARG,MLV_HAUT,"black",screen);
    draw_string(MLV_LARG/2,MLV_HAUT/2,"GAME OVER",POLICE,"red",screen);
    display_window(screen);
}

/* Affiche gameover au centre de l'cran de jeu et attend que l'utilisateur
 * appuie sur une touche
 */
void gameover(Affichage aff, void * str_aff)
{
    /* Passe le terminal en mode bloquant */
    nodelay(stdscr,FALSE);

    /* Affiche le message */
    switch(aff) {
	case TXT:
	    gameover_txt();
	    break;
	case MLV:
	    gameover_mlv(str_aff);
	    break;
    }

    /* Attend une seconde pour avoir le temps de voir le game over */
    sleep(1);

    /* Attend que l'utilisateur appuie sur une touche */
    getch();
}
